CHARACTER_MANGA = """Sakurajima Mai
Azusagawa Sakuta
Koga Tomoe
Futaba Rio
Azusagawa Kaede
Toyohama Nodoka
Kunimi Yûma
Kamisato Saki
Makinohara Shôko
Kano Kotomi
Oga Tatsumi
Kaiser de Emperana Beelzebub IV
Kunieda Aoi
Hildegarde
Alaindelon Bathin de Emuna
Furuichi Takayuki
Ômori Nene
Tôjô Hidetora
Kanzaki Hajime
Natsume Shintarô
Tanimura Chiaki
Hanazawa Yuka
Himekawa Tatsuya
En Ô
Yolda
Nanami Shizuka
Shiroyama Takeshi
Tenma Umatarô
Ochanomizu Hiroshi
A106
Ochanomizu Ran
Tsutsumi Motoko
Ban Shunsaku
Komi Shôko
Tadano Hitohito
Osana Najimi
Agari Himiko
Yadano Makeru
Yamai Ren
Ishigami Senkû
Ôki Taiju
Ogawa Yuzuriha
Shishiô Tsukasa
Kohaku
Chrome
Asagiri Gen
Suika
Kinrô
Ginrô
Ruri
Kaseki
Ishigami Byakuya
Lillian Weinberg
Shamil Volkov
Connie Lee
Darya Nikitina
Yakov Nikitin
Magma
Hyôga
Momiji Homura
Hokutozai Minami
Soyuz
Kokuyô
Loid Forger
Yor Forger
Anya Forger
Franky Franklin
Henry Henderson
Damian Desmond
Becky Blackbell
Sylvia Sherwood
Donovan Desmond
Yuri Briar
Fukuya no Onna Shujin
Camilla
Dominic
Millie
Sharon
Bond Forger
Emile Elman
Ewen Egeberg
Akabane Karma
Koro-sensei
Shiota Nagisa
Kayano Kaede
Karasuma Tadaomi
Irina Jelavic
Nakamura Rio
Terasaka Ryôma
Sugino Tomohito
Isogai Yûma
Maehara Hiroto
Okuda Manami
Kanzaki Yukiko
Asano Gakuhô
Okajima Taiga
Kurahashi Hinano
Ritsu
Hayami Rinka
Kataoka Meg
Red Eye
Horibe Itona
Shiro
Lovro
Okano Hinata
Mimura Kôki
Sugaya Sôsuke
Chiba Ryûnosuke
Takebayashi Kôtarô
Fuwa Yuzuki
Yada Tôka
Asano Gakushû
Yukimura Aguri
Hara Sumire
Hazama Kirara
Araki Teppei
Sakakibara Ren
Kimura Masayoshi
Hiro
Zero Two
Ichigo
Gorô
Zorome
Miku
Ikuno
Mitsuru
Futoshi
Kokoro
Hoshino Ai
Hoshino Aquamarine
Hoshino Ruby
Arima Kana
Kurokawa Akane
MEM-cho
Amemiya Gorô
Tendôji Sarina
Saitô Ichigo
Saitô Miyako
Gotanda Taishi
Kaburagi Masaya
Narushima Melt
Shiranui Frill
Kotobuki Minami
Sumi Yuki
Kumano Nobuyuki
Yuzaki Nasa
Yuzaki Tsukasa
Arisugawa Kaname
Arisugawa Aya
Kaginoji Chitose
Charlotte
Aurora
Edward Elric
Alphonse Elric
Rose
Cornello
Trisha Elric
Winry Rockbell
Van Hohenheim
Roy Mustang
Maes Hughes
Riza Hawkeye
Gracia Hughes
Shô Tucker
Scar
Lyra
Psiren
Fletcher Tringham
Russel Tringham
Lust
Gluttony
Heimans Breda
Jean Havoc
Vato Falman
Kain Fuery
King Bradley
Basque Grand
Envy
Alex Louis Armstrong
Pinako Rockbell
Maria Ross
Sheska
Solf J. Kimblee
Elicia Hughes
Sloth
Paninya
Izumi Curtis
Wrath
Frank Archer
Dante
Greed
Martel
Lujon
Barry the Chopper
Barry the Chopper (humain)
Sig Curtis
Prisoner 48
Nina Tucker
Alexander
Tim Marcoh
Denny Brosh
Dominic LeCoulte
Yoki
Grumman
Dolcetto
Roa
Selim Bradley
Mrs Bradley"""

CHARACTER_MANGA_LIST = CHARACTER_MANGA.split("\n")
